# Security Policy

## Supported Versions

| Version | Supported |
| ------- | --------- |
| 5.x.x   | ✅         |
| < 5.0   | ❌         |

## Reporting a Vulnerability

Please report vulnerabilities via GitHub Security Advisories.
